%global base_name       lang
%global short_name      commons-%{base_name}

Name:           apache-%{short_name}
Version:        2.6
Release:        %mkrel 25
Summary:        Provides a host of helper utilities for the java.lang API
License:        ASL 2.0
Group:          Development/Java
URL:            https://commons.apache.org/%{base_name}
Source0:        https://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Patch0:         0000-Fix-FastDateFormat-for-Java-7-behaviour.patch

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  apache-commons-parent
BuildRequires:  maven-surefire-provider-junit

%description
The standard Java libraries fail to provide enough methods for
manipulation of its core classes. The Commons Lang Component provides
these extra methods.
The Commons Lang Component provides a host of helper utilities for the
java.lang API, notably String manipulation methods, basic numerical
methods, object reflection, creation and serialization, and System
properties. Additionally it contains an inheritable enum type, an
exception structure that supports multiple types of nested-Exceptions
and a series of utilities dedicated to help with building methods, such
as hashCode, toString and equals.

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
%{summary}.

%prep
%setup -q -n %{short_name}-%{version}-src
%patch0 -p1

sed -i 's/\r//' *.txt *.html

%mvn_file  : %{name} %{short_name}
%mvn_alias : org.apache.commons: %{base_name}:%{base_name}

# remove org.apache.commons.lang.enum package
# "enum" is a keyword since Java 4 and cannot be used as an identifier
rm -r src/main/java/org/apache/commons/lang/enum/
rm -r src/test/java/org/apache/commons/lang/enum/
rm src/test/java/org/apache/commons/lang/enums/EnumTest.java

# convert some stray ISO-8859-1 characters to UTF-8
iconv -f ISO-8859-1 -t UTF-8 \
    src/main/java/org/apache/commons/lang/Entities.java > \
    src/main/java/org/apache/commons/lang/Entities.java.utf-8
mv src/main/java/org/apache/commons/lang/Entities.java.utf-8 \
    src/main/java/org/apache/commons/lang/Entities.java

%build
%mvn_build -- \
    -Dcommons.osgi.symbolicName=org.apache.commons.lang \
    -Dmaven.compiler.source=1.8 \
    -Dmaven.compiler.target=1.8 \
    -Dsource=1.8

%install
%mvn_install

%files -f .mfiles
%doc PROPOSAL.html RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Sat Mar 26 2022 umeabot <umeabot> 2.6-25.mga9
+ Revision: 1827927
- Mageia 9 Mass Rebuild

* Mon Aug 24 2020 neoclust <neoclust> 2.6-24.mga8
+ Revision: 1618359
- Fix build against java11

* Sat Feb 15 2020 umeabot <umeabot> 2.6-23.mga8
+ Revision: 1527530
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 2.6-22.mga8
+ Revision: 1422297
- Rebuild to regenerate OSGi metadata

* Thu Sep 20 2018 umeabot <umeabot> 2.6-21.mga7
+ Revision: 1277587
- Mageia 7 Mass Rebuild

* Thu May 18 2017 neoclust <neoclust> 2.6-20.mga6
+ Revision: 1102920
- Rebuild against new apache-parent

* Wed Mar 02 2016 neoclust <neoclust> 2.6-19.mga6
+ Revision: 981899
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 2.6-18.mga6
+ Revision: 975471
- First rebuild of the java stack
- sync package apache-commons-lang with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 2.6-15.mga5
+ Revision: 805747
- Clean rebuild
- Increase release, the previous one is obsoleted
+ dmorgan <dmorgan>
- Restore from Obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 2.6-13.mga5
+ Revision: 745573
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.6-12.mga5
+ Revision: 677813
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 2.6-11.mga4
+ Revision: 537787
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 dmorgan <dmorgan> 2.6-10.mga4
+ Revision: 487711
- Properly specify XMvn s compilerSource option

* Tue Feb 19 2013 dmorgan <dmorgan> 2.6-9.mga3
+ Revision: 399380
- Build with xmvn
- Java Stack Mass Rebuild
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jul 09 2012 dmorgan <dmorgan> 2.6-6.mga3
+ Revision: 268978
- Add backported fix for JDK 1.7

* Sat Jul 23 2011 dmorgan <dmorgan> 2.6-5.mga2
+ Revision: 128023
- Use new add_maven_depmap macro
    - Fix maven3 build

* Wed Apr 27 2011 dmorgan <dmorgan> 2.6-4.mga1
+ Revision: 92239
- Rebuild after bootstrapping
- imported package apache-commons-lang

